@@ -24,6 +24,7 @@
 #include <errno.h>
 
 #include <glib.h>
+#include <dconf.h>
 
 #include "terminal-intl.h"
 
@@ -36,8 +37,6 @@
 #include "terminal-util.h"
 #include "profile-editor.h"
 #include "terminal-encoding.h"
-#include <libmate-desktop/mate-dconf.h>
-#include <libmate-desktop/mate-gsettings.h>
 #include <string.h>
 #include <stdlib.h>
 #include <time.h>
@@ -155,6 +154,70 @@ static TerminalApp *global_app = NULL;
 
 #define ENCODING_LIST_KEY "active-encodings"
 
+
+/* two following functions were copied from libmate-desktop to get rid
+ * of dependency on it
+ *
+ * FIXME: I suspect there's no need for excessive copies, we might use
+ * existing profile list to form GVariant's and write them to GSettings
+ */
+static gboolean
+gsettings_append_strv (GSettings   *settings,
+                            const gchar *key,
+                            const gchar *value)
+{
+    gchar    **old;
+    gchar    **new;
+    gint       size;
+    gboolean   retval;
+
+    old = g_settings_get_strv (settings, key);
+
+    for (size = 0; old[size] != NULL; size++);
+
+    size += 1; /* appended value */
+    size += 1; /* NULL */
+
+    new = g_realloc_n (old, size, sizeof (gchar *));
+
+    new[size - 2] = g_strdup (value);
+    new[size - 1] = NULL;
+
+    retval = g_settings_set_strv (settings, key,
+                                  (const gchar **) new);
+
+    g_strfreev (new);
+
+    return retval;
+}
+
+static gboolean
+gsettings_remove_all_from_strv (GSettings   *settings,
+                                     const gchar *key,
+                                     const gchar *value)
+{
+    GArray    *array;
+    gchar    **old;
+    gint       i;
+    gboolean   retval;
+
+    old = g_settings_get_strv (settings, key);
+    array = g_array_new (TRUE, TRUE, sizeof (gchar *));
+
+    for (i = 0; old[i] != NULL; i++) {
+        if (g_strcmp0 (old[i], value) != 0)
+            array = g_array_append_val (array, old[i]);
+    }
+
+    retval = g_settings_set_strv (settings, key,
+                                  (const gchar **) array->data);
+
+    g_strfreev (old);
+    g_array_free (array, TRUE);
+
+    return retval;
+}
+
 /* Helper functions */
 
 static GdkScreen*
@@ -324,15 +387,17 @@ terminal_app_delete_profile (TerminalApp *app,
 	profile_name = terminal_profile_get_property_string (profile, TERMINAL_PROFILE_NAME);
 	profile_dir = g_strconcat (CONF_PROFILE_PREFIX, profile_name, "/", NULL);
 
-	mate_gsettings_remove_all_from_strv (app->settings_global, PROFILE_LIST_KEY, profile_name);
+	gsettings_remove_all_from_strv (app->settings_global, PROFILE_LIST_KEY, profile_name);
 
 	/* And remove the profile directory */
-	if (!mate_dconf_recursive_reset (profile_dir, &error))
+	DConfClient *client = dconf_client_new ();
+	if (!dconf_client_write_sync (client, profile_dir, NULL, NULL, NULL, &error))
 	{
 		g_warning ("Failed to recursively unset %s: %s\n", profile_dir, error->message);
 		g_error_free (error);
 	}
 
+	g_object_unref (client);
 	g_free (profile_dir);
 }
 
@@ -627,10 +692,7 @@ profile_list_delete_button_clicked_cb (GtkWidget *button,
 	                        GTK_STOCK_DELETE,
 	                        GTK_RESPONSE_ACCEPT,
 	                        NULL);
-	gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
-	        GTK_RESPONSE_ACCEPT,
-	        GTK_RESPONSE_REJECT,
-	        -1);
+
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 	                                 GTK_RESPONSE_ACCEPT);
 
@@ -1099,7 +1161,7 @@ new_profile_response_cb (GtkWidget *new_profile_dialog,
 		                     new_profile /* adopts the refcount */);
 
 		/* And now save the new profile name to GSettings */
-		mate_gsettings_append_strv (app->settings_global,
+		gsettings_append_strv (app->settings_global,
 						PROFILE_LIST_KEY,
 						new_profile_name);
 
@@ -1146,12 +1208,12 @@ terminal_app_new_profile (TerminalApp     *app,
 {
 	if (app->new_profile_dialog == NULL)
 	{
-		GtkWidget *create_button, *table, *name_label, *name_entry, *base_label, *combo;
+		GtkWidget *create_button, *grid, *name_label, *name_entry, *base_label, *combo;
 
 		if (!terminal_util_load_builder_file ("profile-new-dialog.ui",
 		                                      "new-profile-dialog", &app->new_profile_dialog,
 		                                      "new-profile-create-button", &create_button,
-		                                      "new-profile-table", &table,
+		                                      "new-profile-grid", &grid,
 		                                      "new-profile-name-label", &name_label,
 		                                      "new-profile-name-entry", &name_entry,
 		                                      "new-profile-base-label", &base_label,
@@ -1174,16 +1236,12 @@ terminal_app_new_profile (TerminalApp     *app,
 
 		/* the base profile option menu */
 		combo = profile_combo_box_new (app);
-		gtk_table_attach_defaults (GTK_TABLE (table), combo, 1, 2, 1, 2);
+		gtk_grid_attach (GTK_GRID (grid), combo, 2, 1, 1, 1);
 		g_object_set_data (G_OBJECT (app->new_profile_dialog), "base_option_menu", combo);
 		terminal_util_set_atk_name_description (combo, NULL, _("Choose base profile"));
 
 		gtk_label_set_mnemonic_widget (GTK_LABEL (base_label), combo);
 
-		gtk_dialog_set_alternative_button_order (GTK_DIALOG (app->new_profile_dialog),
-		        GTK_RESPONSE_ACCEPT,
-		        GTK_RESPONSE_CANCEL,
-		        -1);
 		gtk_dialog_set_default_response (GTK_DIALOG (app->new_profile_dialog), GTK_RESPONSE_ACCEPT);
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (app->new_profile_dialog), GTK_RESPONSE_ACCEPT, FALSE);
 	}
